@@ -49,258 +49,65 @@ void * memalign (size_t align, size_t size);
 static void video_frame_alloc(gavl_video_frame_t * ret,
                               const gavl_video_format_t * format, int align)
   {
-  switch(format->pixelformat)
+  int planar;
+
+  if(format->pixelformat == GAVL_PIXELFORMAT_NONE)
     {
-    case GAVL_GRAY_8:
-      ret->strides[0] = format->frame_width;
-      if(align)
-        ALIGN(ret->strides[0]);
-      ret->planes[0] = memalign(ALIGNMENT_BYTES,
-                                ret->strides[0] * format->frame_height);
-      break;
-    case GAVL_GRAYA_16:
-    case GAVL_GRAY_16:
-    case GAVL_RGB_15:
-    case GAVL_BGR_15:
-    case GAVL_RGB_16:
-    case GAVL_BGR_16:
-      ret->strides[0] = format->frame_width*2;
-      if(align)
-        ALIGN(ret->strides[0]);
-      ret->planes[0] = memalign(ALIGNMENT_BYTES,
-                             ret->strides[0] * format->frame_height);
-      break;
-    case GAVL_RGB_24:
-    case GAVL_BGR_24:
-      ret->strides[0] = format->frame_width*3;
-      if(align)
-        ALIGN(ret->strides[0]);
-      ret->planes[0] = memalign(ALIGNMENT_BYTES,
-                             ret->strides[0] * format->frame_height);
-      break;
-    case GAVL_RGB_32:
-    case GAVL_BGR_32:
-    case GAVL_YUVA_32:
-    case GAVL_GRAYA_32:
-      ret->strides[0] = format->frame_width*4;
-      if(align)
-        ALIGN(ret->strides[0]);
-      ret->planes[0] = memalign(ALIGNMENT_BYTES,
-                             ret->strides[0] * format->frame_height);
-      break;
-    case GAVL_RGBA_32:
-      ret->strides[0] = format->frame_width*4;
-      if(align)
-        ALIGN(ret->strides[0]);
-      ret->planes[0] = memalign(ALIGNMENT_BYTES,
-                             ret->strides[0] * format->frame_height);
-      break;
-    case GAVL_RGB_48:
-      ret->strides[0] = format->frame_width*6;
-      if(align)
-        ALIGN(ret->strides[0]);
-      ret->planes[0] = memalign(ALIGNMENT_BYTES,
-                             ret->strides[0] * format->frame_height);
-      break;
-    case GAVL_RGBA_64:
-    case GAVL_YUVA_64:
-      ret->strides[0] = format->frame_width*8;
-      if(align)
-        ALIGN(ret->strides[0]);
-      ret->planes[0] = memalign(ALIGNMENT_BYTES,
-                             ret->strides[0] * format->frame_height);
-      break;
-    case GAVL_GRAY_FLOAT:
-      ret->strides[0] = format->frame_width*sizeof(float);
-      if(align)
-        ALIGN(ret->strides[0]);
-      ret->planes[0] = memalign(ALIGNMENT_BYTES,
-                                ret->strides[0] * format->frame_height);
-      break;
-    case GAVL_GRAYA_FLOAT:
-      ret->strides[0] = 2*format->frame_width*sizeof(float);
-      if(align)
-        ALIGN(ret->strides[0]);
-      ret->planes[0] = memalign(ALIGNMENT_BYTES,
-                                ret->strides[0] * format->frame_height);
-      break;
-
-    case GAVL_RGB_FLOAT:
-    case GAVL_YUV_FLOAT:
-      ret->strides[0] = format->frame_width*3*sizeof(float);
-      if(align)
-        ALIGN(ret->strides[0]);
-      ret->planes[0] = memalign(ALIGNMENT_BYTES,
-                             ret->strides[0] * format->frame_height);
-      break;
-    case GAVL_RGBA_FLOAT:
-    case GAVL_YUVA_FLOAT:
-      ret->strides[0] = format->frame_width*4*sizeof(float);
-      if(align)
-        ALIGN(ret->strides[0]);
-      ret->planes[0] = memalign(ALIGNMENT_BYTES,
-                             ret->strides[0] * format->frame_height);
-      break;
-    case GAVL_YUY2:
-    case GAVL_UYVY:
-      ret->strides[0] = format->frame_width*2;
-      if(align)
-        ALIGN(ret->strides[0]);
-      ret->planes[0] = memalign(ALIGNMENT_BYTES,
-                             ret->strides[0] * format->frame_height);
-      break;
-    case GAVL_YUV_420_P:
-    case GAVL_YUVJ_420_P:
-      ret->strides[0] = format->frame_width;
-      ret->strides[1] = (format->frame_width+1)/2;
-      ret->strides[2] = (format->frame_width+1)/2;
-
-      if(align)
-        {
-        ALIGN(ret->strides[0]);
-        ALIGN(ret->strides[1]);
-        ALIGN(ret->strides[2]);
-        }
-      ret->planes[0] = memalign(ALIGNMENT_BYTES,
-                             ret->strides[0]*format->frame_height+
-                             ret->strides[1]*((format->frame_height+1)/2)+
-                             ret->strides[2]*((format->frame_height+1)/2));
-      ret->planes[1] = ret->planes[0] + ret->strides[0]*format->frame_height;
-      ret->planes[2] = ret->planes[1] + ret->strides[1]*((format->frame_height+1)/2);
-      break;
-    case GAVL_YUV_410_P:
-      ret->strides[0] = format->frame_width;
-      ret->strides[1] = (format->frame_width+3)/4;
-      ret->strides[2] = (format->frame_width+3)/4;
-
-      if(align)
-        {
-        ALIGN(ret->strides[0]);
-        ALIGN(ret->strides[1]);
-        ALIGN(ret->strides[2]);
-        }
-      
-      ret->planes[0] = memalign(ALIGNMENT_BYTES,
-                             ret->strides[0]*format->frame_height+
-                             ret->strides[1]*((format->frame_height+3)/4)+
-                             ret->strides[2]*((format->frame_height+3)/4));
-      ret->planes[1] = ret->planes[0] + ret->strides[0]*format->frame_height;
-      ret->planes[2] = ret->planes[1] + ret->strides[1]*((format->frame_height+3)/4);
-      break;
-    case GAVL_YUV_422_P:
-    case GAVL_YUVJ_422_P:
-      ret->strides[0] = format->frame_width;
-      ret->strides[1] = (format->frame_width+1)/2;
-      ret->strides[2] = (format->frame_width+1)/2;
-
-      if(align)
-        {
-        ALIGN(ret->strides[0]);
-        ALIGN(ret->strides[1]);
-        ALIGN(ret->strides[2]);
-        }
-      
-      ret->planes[0] = memalign(ALIGNMENT_BYTES,
-                                ret->strides[0]*format->frame_height+
-                                ret->strides[1]*format->frame_height+
-                                ret->strides[2]*format->frame_height);
-
-      ret->planes[1] = ret->planes[0] + ret->strides[0]*format->frame_height;
-      ret->planes[2] = ret->planes[1] + ret->strides[1]*format->frame_height;
-      break;
-    case GAVL_YUV_422_P_16:
-      ret->strides[0] = format->frame_width*2;
-      ret->strides[1] = ((format->frame_width+1)/2)*2;
-      ret->strides[2] = ((format->frame_width+1)/2)*2;
-      
-      if(align)
-        {
-        ALIGN(ret->strides[0]);
-        ALIGN(ret->strides[1]);
-        ALIGN(ret->strides[2]);
-        }
-      
-      ret->planes[0] = memalign(ALIGNMENT_BYTES,
-                             ret->strides[0]*format->frame_height+
-                             ret->strides[1]*format->frame_height+
-                             ret->strides[2]*format->frame_height);
-
-      ret->planes[1] = ret->planes[0] + ret->strides[0]*format->frame_height;
-      ret->planes[2] = ret->planes[1] + ret->strides[1]*format->frame_height;
-      break;
-    case GAVL_YUV_411_P:
-      ret->strides[0] = format->frame_width;
-      ret->strides[1] = (format->frame_width+3)/4;
-      ret->strides[2] = (format->frame_width+3)/4;
-
-      if(align)
-        {
-        ALIGN(ret->strides[0]);
-        ALIGN(ret->strides[1]);
-        ALIGN(ret->strides[2]);
-        }
-      
-      ret->planes[0] = memalign(ALIGNMENT_BYTES,
-                             ret->strides[0]*format->frame_height+
-                             ret->strides[1]*format->frame_height+
-                             ret->strides[2]*format->frame_height);
-
-      ret->planes[1] = ret->planes[0] + ret->strides[0]*format->frame_height;
-      ret->planes[2] = ret->planes[1] + ret->strides[1]*format->frame_height;
-      break;
-    case GAVL_YUV_444_P:
-    case GAVL_YUVJ_444_P:
-      ret->strides[0] = format->frame_width;
-      ret->strides[1] = format->frame_width;
-      ret->strides[2] = format->frame_width;
-
-      if(align)
-        {
-        ALIGN(ret->strides[0]);
-        ALIGN(ret->strides[1]);
-        ALIGN(ret->strides[2]);
-        }
-      
-      ret->planes[0] = memalign(ALIGNMENT_BYTES,
-                                ret->strides[0]*format->frame_height+
-                                ret->strides[1]*format->frame_height+
-                                ret->strides[2]*format->frame_height);
-
-      ret->planes[1] = ret->planes[0] + ret->strides[0]*format->frame_height;
-      ret->planes[2] = ret->planes[1] + ret->strides[1]*format->frame_height;
-      break;
-    case GAVL_YUV_444_P_16:
-      ret->strides[0] = format->frame_width*2;
-      ret->strides[1] = format->frame_width*2;
-      ret->strides[2] = format->frame_width*2;
-
-      if(align)
-        {
-        ALIGN(ret->strides[0]);
-        ALIGN(ret->strides[1]);
-        ALIGN(ret->strides[2]);
-        }
-      
-      ret->planes[0] = memalign(ALIGNMENT_BYTES,
-                                ret->strides[0]*format->frame_height+
-                                ret->strides[1]*format->frame_height+
-                                ret->strides[2]*format->frame_height);
-
-      ret->planes[1] = ret->planes[0] + ret->strides[0]*format->frame_height;
-      ret->planes[2] = ret->planes[1] + ret->strides[1]*format->frame_height;
-      break;
-    case GAVL_PIXELFORMAT_NONE:
-      fprintf(stderr, "Pixelformat not specified for video frame\n");
-      return;
+    fprintf(stderr, "Pixelformat not specified for video frame\n");
+    return;
     }
+  planar = gavl_pixelformat_is_planar(format->pixelformat);
+  
+  if(planar)
+    {
+    int sub_h;
+    int sub_v;
+    int bpc;
+    
+    gavl_pixelformat_chroma_sub(format->pixelformat, &sub_h, &sub_v);
+    
+    bpc = gavl_pixelformat_bytes_per_component(format->pixelformat);
 
+    if(!ret->strides[0])
+      {
+      ret->strides[0] = bpc * format->frame_width;
+      ret->strides[1] = bpc * ((format->frame_width + sub_h - 1) / sub_h);
+      ret->strides[2] = ret->strides[1];
+      
+      if(align)
+        {
+        ALIGN(ret->strides[0]);
+        ALIGN(ret->strides[1]);
+        ALIGN(ret->strides[2]);
+        }
+      }
+    
+    ret->planes[0] = memalign(ALIGNMENT_BYTES,
+                              ret->strides[0]*format->frame_height+
+                              ret->strides[1]*((format->frame_height+sub_v-1)/sub_v)+
+                              ret->strides[2]*((format->frame_height+sub_v-1)/sub_v));
+    ret->planes[1] = ret->planes[0] + ret->strides[0]*format->frame_height;
+    ret->planes[2] = ret->planes[1] + ret->strides[1]*((format->frame_height+sub_v-1)/sub_v);
+    }
+  else // Packed
+    {
+    if(!ret->strides[0])
+      {
+      ret->strides[0] =
+        format->frame_width * gavl_pixelformat_bytes_per_pixel(format->pixelformat);
+      if(align)
+        ALIGN(ret->strides[0]);
+      }
+    ret->planes[0] = memalign(ALIGNMENT_BYTES,
+                              ret->strides[0] * format->frame_height);
+    }
   }
 
 static void video_frame_free(gavl_video_frame_t * frame)
   {
   if(frame->planes[0])
     free(frame->planes[0]);
-  frame->planes[0] = (uint8_t*)0;
+  frame->planes[0] = NULL;
   }
 
 gavl_video_frame_t * gavl_video_frame_create(const gavl_video_format_t * format)
@@ -330,7 +137,7 @@ void gavl_video_frame_destroy(gavl_video_frame_t * frame)
 
 void gavl_video_frame_null(gavl_video_frame_t* frame)
   {
-  frame->planes[0] = (uint8_t*)0;
+  frame->planes[0] = NULL;
   }
 
 void gavl_video_frame_clear_mask(gavl_video_frame_t * frame,
@@ -1038,7 +845,7 @@ static flip_scanline_func find_flip_scanline_func(gavl_pixelformat_t csp)
     case GAVL_PIXELFORMAT_NONE:
       break;
     }
-  return (flip_scanline_func)0;
+  return NULL;
   }
 
 void gavl_video_frame_copy_flip_x(const gavl_video_format_t * format,
@@ -1510,7 +1317,7 @@ void gavl_video_frame_fill(gavl_video_frame_t * frame,
   uint16_t packed_16;
   uint8_t  packed_32[4];
   uint16_t packed_64[4];
-  float color_float[2];
+  float color_float[4];
 
   gavl_init_memcpy();
   
@@ -1744,19 +1551,27 @@ void gavl_video_frame_set_planes(gavl_video_frame_t * frame,
   int i;
   int sub_h, sub_v;
   int advance;
-  int num_planes = gavl_pixelformat_num_planes(format->pixelformat);
+  int num_planes;
   if(!frame->strides[0])
     gavl_video_frame_set_strides(frame, format);
 
-  gavl_pixelformat_chroma_sub(format->pixelformat, &sub_h, &sub_v);
-
-  for(i = 0; i < num_planes; i++)
+  if(buffer)
     {
-    frame->planes[i] = buffer;
-    advance = frame->strides[i] * format->frame_height;
-    if(i)
-      advance /= sub_v;
-    buffer += advance;
+    num_planes = gavl_pixelformat_num_planes(format->pixelformat);
+    gavl_pixelformat_chroma_sub(format->pixelformat, &sub_h, &sub_v);
+  
+    for(i = 0; i < num_planes; i++)
+      {
+      frame->planes[i] = buffer;
+      advance = frame->strides[i] * format->frame_height;
+      if(i)
+        advance /= sub_v;
+      buffer += advance;
+      }
+    }
+  else
+    {
+    video_frame_alloc(frame, format, 0);
     }
   
   }
