@@ -1,7 +1,7 @@
 /*****************************************************************
  * gavl - a general purpose audio/video processing library
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -111,7 +111,7 @@ void gavl_volume_control_set_format(gavl_volume_control_t * v,
   {
   gavl_volume_funcs_t * funcs;
 
-  gavl_audio_format_copy(&(v->format), format);
+  gavl_audio_format_copy(&v->format, format);
   
   funcs = gavl_volume_funcs_create();
   
